# Core Mass Subsystem

The core mass subsystem is responsible for calculating the mass properties of the aircraft.
This includes the empty weight, fuel weight, payload weight, and other mass properties.

```{note}
This section is under further development.
```
